@@ -32,6 +32,7 @@ import com.google.common.util.concurrent.SettableFuture;
 import io.netty.channel.Channel;
 import io.netty.channel.ChannelPromise;
 import io.netty.channel.DefaultChannelPromise;
+import io.netty.channel.EventLoop;
 
 import java.io.IOException;
 import java.util.concurrent.CountDownLatch;
@@ -66,6 +67,10 @@ public class ReadEntryProcessorTest {
         when(requestProcessor.getRequestStats()).thenReturn(new RequestStats(NullStatsLogger.INSTANCE));
         when(channel.voidPromise()).thenReturn(mock(ChannelPromise.class));
         when(channel.writeAndFlush(any())).thenReturn(mock(ChannelPromise.class));
+
+        EventLoop eventLoop = mock(EventLoop.class);
+        when(eventLoop.inEventLoop()).thenReturn(true);
+        when(channel.eventLoop()).thenReturn(eventLoop);
     }
 
     @Test
@@ -87,20 +92,21 @@ public class ReadEntryProcessorTest {
         CountDownLatch latch = new CountDownLatch(1);
         doAnswer(invocationOnMock -> {
             writtenObject.set(invocationOnMock.getArgument(0));
+            promise.setSuccess();
             latch.countDown();
             return promise;
-        }).when(channel).writeAndFlush(any(Response.class), any());
+        }).when(channel).writeAndFlush(any(Response.class));
 
         ExecutorService service = Executors.newCachedThreadPool();
         long ledgerId = System.currentTimeMillis();
         ReadRequest request = new ReadRequest(BookieProtocol.CURRENT_PROTOCOL_VERSION, ledgerId,
                 1, BookieProtocol.FLAG_DO_FENCING, new byte[]{});
-        ReadEntryProcessor processor = ReadEntryProcessor.create(request, channel, requestProcessor, service);
+        ReadEntryProcessor processor = ReadEntryProcessor.create(request, channel, requestProcessor, service, true);
         processor.run();
 
         fenceResult.set(result);
         latch.await();
-        verify(channel, times(1)).writeAndFlush(any(Response.class), any());
+        verify(channel, times(1)).writeAndFlush(any(Response.class));
 
         assertTrue(writtenObject.get() instanceof Response);
         Response response = (Response) writtenObject.get();
@@ -108,6 +114,7 @@ public class ReadEntryProcessorTest {
         assertEquals(ledgerId, response.getLedgerId());
         assertEquals(BookieProtocol.READENTRY, response.getOpCode());
         assertEquals(errorCode, response.getErrorCode());
+        service.shutdown();
     }
 
     @Test
@@ -128,19 +135,20 @@ public class ReadEntryProcessorTest {
         CountDownLatch latch = new CountDownLatch(1);
         doAnswer(invocationOnMock -> {
             writtenObject.set(invocationOnMock.getArgument(0));
+            promise.setSuccess();
             latch.countDown();
             return promise;
-        }).when(channel).writeAndFlush(any(Response.class), any());
+        }).when(channel).writeAndFlush(any(Response.class));
 
         long ledgerId = System.currentTimeMillis();
         ReadRequest request = new ReadRequest(BookieProtocol.CURRENT_PROTOCOL_VERSION, ledgerId,
                 1, BookieProtocol.FLAG_DO_FENCING, new byte[]{});
-        ReadEntryProcessor processor = ReadEntryProcessor.create(request, channel, requestProcessor, null);
+        ReadEntryProcessor processor = ReadEntryProcessor.create(request, channel, requestProcessor, null, true);
         fenceResult.set(result);
         processor.run();
 
         latch.await();
-        verify(channel, times(1)).writeAndFlush(any(Response.class), any());
+        verify(channel, times(1)).writeAndFlush(any(Response.class));
 
         assertTrue(writtenObject.get() instanceof Response);
         Response response = (Response) writtenObject.get();
@@ -157,18 +165,19 @@ public class ReadEntryProcessorTest {
         CountDownLatch latch = new CountDownLatch(1);
         doAnswer(invocationOnMock -> {
             writtenObject.set(invocationOnMock.getArgument(0));
+            promise.setSuccess();
             latch.countDown();
             return promise;
-        }).when(channel).writeAndFlush(any(Response.class), any());
+        }).when(channel).writeAndFlush(any(Response.class));
 
         long ledgerId = System.currentTimeMillis();
         ReadRequest request = new ReadRequest(BookieProtocol.CURRENT_PROTOCOL_VERSION, ledgerId,
                 1, (short) 0, new byte[]{});
-        ReadEntryProcessor processor = ReadEntryProcessor.create(request, channel, requestProcessor, null);
+        ReadEntryProcessor processor = ReadEntryProcessor.create(request, channel, requestProcessor, null, true);
         processor.run();
 
         latch.await();
-        verify(channel, times(1)).writeAndFlush(any(Response.class), any());
+        verify(channel, times(1)).writeAndFlush(any(Response.class));
 
         assertTrue(writtenObject.get() instanceof Response);
         Response response = (Response) writtenObject.get();
